product_list <- 'box(
  title = "Product List",
  width = NULL,
  status = "primary",
  productList(
    productListItem(
      src = "https://www.pngmart.com/files/1/Haier-TV-PNG.png", 
      productTitle = "Samsung TV", 
      productPrice = "$1800", 
      priceColor = "warning",
      "This is an amazing TV, but I do not like TV!"
    ),
    productListItem(
      src = "https://upload.wikimedia.org/wikipedia/commons/7/77/IMac_Pro.svg", 
      productTitle = "Imac 27", 
      productPrice = "$4999", 
      priceColor = "danger",
      "This is were I spend most of my time!"
    )
  )
)'